@@ -5,8 +5,8 @@
 #' @usage modelfuzzy_kaoliu(datadea,
 #'                   dmu_eval = NULL,
 #'                   kaoliu_modelname = c("basic", "additive", "addsupereff", 
-#'                                        "deaps", "fdh", "multiplier", "nonradial",
-#'                                        "sbmeff", "sbmsupereff", "supereff"),
+#'                     "deaps", "fdh", "multiplier", "nonradial", "profit",
+#'                     "rdm", "sbmeff", "sbmsupereff", "supereff"),
 #'                   alpha = 1,
 #'                   ...)
 #' 
@@ -14,8 +14,8 @@
 #' @param dmu_eval A numeric vector containing which DMUs have to be evaluated.
 #' If \code{NULL} (default), all DMUs are considered.
 #' @param kaoliu_modelname a string containing the name of the model.
-#' @param alpha A numeric vector with the alpha-cuts (in [0,1]). If \code{alpha}>1, it
-#'              determines the number of alpha-cuts, equispatially distributed in [0,1]. 
+#' @param alpha A numeric vector with the alpha-cuts (in [0,1]). If \code{alpha}>1,
+#' it determines the number of alpha-cuts, equispatially distributed in [0,1]. 
 #' @param ... \code{dmu_ref}, \code{orientation}, \code{rts} and other model parameters.
 #'   
 #' @return An object of class \code{deadata_fuzzy}.
@@ -33,17 +33,28 @@
 #' University of Valencia (Spain)
 #'  
 #' @references 
-#' Boscá, J.E.; Liern, V.; Sala, R.; Martínez, A. (2011). "Ranking Decision Making Units by Means of Soft Computing DEA Models". International Journal of Uncertainty, Fuzziness and Knowledge-Based Systems, 19(1), p.115-134. 
+#' Boscá, J.E.; Liern, V.; Sala, R.; Martínez, A. (2011). "Ranking Decision Making
+#' Units by Means of Soft Computing DEA Models". International Journal of Uncertainty,
+#' Fuzziness and Knowledge-Based Systems, 19(1), p.115-134. 
 #' 
-#' Emrouznejad, A.; Tavana, M.; Hatami-Marbini, A. (2014). “The State of the Art in Fuzzy Data Envelopment Analysis”, in A. Emrouznejad and M. Tavana (eds.), Performance Measurement with Fuzzy Data Envelopment Analysis. Studies in Fuzziness and Soft Computing 309. Springer, Berlin.
+#' Emrouznejad, A.; Tavana, M.; Hatami-Marbini, A. (2014). “The State of the Art
+#' in Fuzzy Data Envelopment Analysis”, in A. Emrouznejad and M. Tavana (eds.),
+#' Performance Measurement with Fuzzy Data Envelopment Analysis. Studies in Fuzziness
+#' and Soft Computing 309. Springer, Berlin.
 #' 
-#' Hatami-Marbini, A.; Emrouznejad, A.; Tavana, M. (2011). "A Taxonomy and Review of the Fuzzy Data Envelopment Analysis Literature: Two Decades in the Making", European Journal of Operational Research, 214, 457–472.
+#' Hatami-Marbini, A.; Emrouznejad, A.; Tavana, M. (2011). "A Taxonomy and Review
+#' of the Fuzzy Data Envelopment Analysis Literature: Two Decades in the Making",
+#' European Journal of Operational Research, 214, 457–472.
 #' 
-#' Kao, C.; Liu, S.T. (2000). “Fuzzy efficiency measures in data envelopment analysis, Fuzzy Sets and Systems”, 119, 149–160.
+#' Kao, C.; Liu, S.T. (2000). “Fuzzy efficiency measures in data envelopment analysis,
+#' Fuzzy Sets and Systems”, 119, 149–160.
 #' 
-#' Kao, C., Liu, S.T., (2000). “Data envelopment analysis with missing data: An application to university libraries in Taiwan”, Journal of the Operational Research Society, 51, 897–905. 
+#' Kao, C., Liu, S.T., (2000). “Data envelopment analysis with missing data:
+#' An application to university libraries in Taiwan”, Journal of the Operational
+#' Research Society, 51, 897–905. 
 #' 
-#' Kao, C., Liu, S.T. (2003). “A mathematical programming approach to fuzzy efficiency ranking”, International Journal of Production Economics, 85.
+#' Kao, C., Liu, S.T. (2003). “A mathematical programming approach to fuzzy
+#' efficiency ranking”, International Journal of Production Economics, 85.
 #' 
 #' @examples 
 #' # Example 1. 
@@ -79,7 +90,8 @@
 #' names(eff) <- c("eff_lower", "eff_upper")
 #' eff
 #' 
-#' @seealso \code{\link{model_basic}}, \code{\link{model_multiplier}}, \code{\link{modelfuzzy_possibilistic}}, \code{\link{modelfuzzy_guotanaka}}
+#' @seealso \code{\link{model_basic}}, \code{\link{model_multiplier}},
+#' \code{\link{modelfuzzy_possibilistic}}, \code{\link{modelfuzzy_guotanaka}}
 #' 
 #' @import lpSolve
 #' 
@@ -89,8 +101,8 @@ modelfuzzy_kaoliu <-
   function(datadea,
            dmu_eval = NULL,
            kaoliu_modelname = c("basic", "additive", "addsupereff", "deaps", "fdh",
-                                "multiplier", "nonradial", "sbmeff", "sbmsupereff",
-                                "supereff"),
+                                "multiplier", "nonradial", "profit", "rdm", "sbmeff",
+                                "sbmsupereff", "supereff"),
            alpha = 1,
            ...) {
  
@@ -118,33 +130,54 @@ modelfuzzy_kaoliu <-
   arguments <- list(...)
   
   # Checking undesirable io and rts
-  if (!is.null(datadea$ud_inputs) || !is.null(datadea$ud_outputs)) {
+  kkud1 <- FALSE # Flag for undesirable i/o basic non-directional
+  kkud2 <- FALSE # Flag for undesirable i/o basic directional, RDM or SBM
+  ud_inputs <- datadea$ud_inputs
+  ud_outputs <- datadea$ud_outputs
+  if (!is.null(ud_inputs) || !is.null(ud_outputs)) {
     if (kaoliu_modelname %in% c("basic", "fdh")) {
-      datadea_old <- datadea
-      res_und <- undesirable_basic(datadea = datadea, vtrans_i = arguments$vtrans_i, vtrans_o = arguments$vtrans_o)
-      datadea <- res_und$u_datadea
-      vtrans_i <- res_und$vtrans_i
-      vtrans_o <- res_und$vtrans_o
       if (is.null(arguments$orientation)) {
         arguments$orientation <- "io"
       }
-      if (!is.null(datadea$ud_inputs) && (arguments$orientation != "io")) {
-        warning("Undesirable (good) inputs with no input-oriented model.")
-      }
-      if (!is.null(datadea$ud_outputs) && (arguments$orientation != "oo")) {
-        warning("Undesirable (bad) outputs with no output-oriented model.")
-      }
-      if (is.null(arguments$rts)) {
-        arguments$rts <- "crs"
-      }
-      if (arguments$rts != "vrs") {
-        #arguments$rts <- "vrs"
-        warning("Returns to scale may be changed to variable (vrs) because there is data with undesirable inputs/outputs.")
+      if (arguments$orientation != "dir") {
+        kkud1 <- TRUE
+        if (!is.null(ud_inputs) && (arguments$orientation != "io")) {
+          warning("Undesirable (good) inputs with no input-oriented model.")
+        }
+        if (!is.null(ud_outputs) && (arguments$orientation != "oo")) {
+          warning("Undesirable (bad) outputs with no output-oriented model.")
+        }
+        if (is.null(arguments$rts)) {
+          arguments$rts <- "crs"
+        }
+        if (arguments$rts != "vrs") {
+          #arguments$rts <- "vrs"
+          warning("Returns to scale may be changed to variable (vrs) because there
+                  is data with undesirable inputs/outputs.")
+        }
+      } else {
+        kkud2 <- TRUE
       }
+    } else if ((kaoliu_modelname == "sbmeff") || (kaoliu_modelname == "rdm")) {
+      kkud2 <- TRUE
     } else {
-      warning("This model does not take into account the undesirable feature for inputs/outputs.")
+      warning("This model does not take into account the undesirable feature for
+              inputs/outputs.")
     }
   }
+  ud_inputskkud2 <- NULL
+  ud_outputskkud2 <- NULL
+  if (kkud1) {
+    datadea_old <- datadea
+    res_und <- undesirable_basic(datadea = datadea, vtrans_i = arguments$vtrans_i,
+                                 vtrans_o = arguments$vtrans_o)
+    datadea <- res_und$u_datadea
+    vtrans_i <- res_und$vtrans_i
+    vtrans_o <- res_und$vtrans_o
+  } else if (kkud2) {
+    ud_inputskkud2 <- ud_inputs
+    ud_outputskkud2 <- ud_outputs
+  }
   
   input.mL <- datadea$input$mL
   output.mL <- datadea$output$mL
@@ -179,6 +212,19 @@ modelfuzzy_kaoliu <-
     output.L <- output.mL - output.dL * (1 - a)
     output.U <- output.mR + output.dR * (1 - a)
     
+    if (kkud2) { # Undesirable i/o for directional or SBM models
+      if (!is.null(ud_inputs)){
+        aux <- input.L[ud_inputs, ]
+        input.L[ud_inputs, ] <- input.U[ud_inputs, ]
+        input.U[ud_inputs, ] <- aux
+      }
+      if (!is.null(ud_outputs)){
+        aux <- output.L[ud_outputs, ]
+        output.L[ud_outputs, ] <- output.U[ud_outputs, ]
+        output.U[ud_outputs, ] <- aux
+      }
+    }
+    
     DMU.W <- vector(mode = "list", length = nde)
     names(DMU.W) <- dmunames[dmu_eval]
     DMU.B <- DMU.W
@@ -198,7 +244,9 @@ modelfuzzy_kaoliu <-
                                   nc_inputs = datadea$nc_inputs,
                                   nc_outputs = datadea$nc_outputs,
                                   nd_inputs = datadea$nd_inputs,
-                                  nd_outputs = datadea$nd_outputs),
+                                  nd_outputs = datadea$nd_outputs,
+                                  ud_inputs = ud_inputskkud2,
+                                  ud_outputs = ud_outputskkud2),
                              class = "deadata")
       deasol <- do.call(model_modelname, list(datadea = datadea.W, dmu_eval = jj, ...))
       DMU.W[[j]] <- deasol$DMU[[1]]
@@ -214,26 +262,26 @@ modelfuzzy_kaoliu <-
                                   nc_inputs = datadea$nc_inputs,
                                   nc_outputs = datadea$nc_outputs,
                                   nd_inputs = datadea$nd_inputs,
-                                  nd_outputs = datadea$nd_outputs),
+                                  nd_outputs = datadea$nd_outputs,
+                                  ud_inputs = ud_inputskkud2,
+                                  ud_outputs = ud_outputskkud2),
                              class = "deadata")
       deasol <- do.call(model_modelname, list(datadea = datadea.B, dmu_eval = jj, ...))
       DMU.B[[j]] <- deasol$DMU[[1]]
       
     }
     
-    if (!is.null(datadea$ud_inputs) || !is.null(datadea$ud_outputs)) {
-      if (kaoliu_modelname %in% c("basic", "fdh")) { 
-        input.L <- datadea_old$input$mL - datadea_old$input$dL * (1 - a)
-        input.U <- datadea_old$input$mR + datadea_old$input$dR * (1 - a)
-        output.L <- datadea_old$output$mL - datadea_old$output$dL * (1 - a)
-        output.U <- datadea_old$output$mR + datadea_old$output$dR * (1 - a)
-        if (!is.null(DMU.W[[1]]$target_input)) {
-          for (j in 1:nde) {
-            DMU.W[[j]]$target_input[datadea$ud_inputs] <- vtrans_i - DMU.W[[j]]$target_input[datadea$ud_inputs]
-            DMU.W[[j]]$target_output[datadea$ud_outputs] <- vtrans_o - DMU.W[[j]]$target_output[datadea$ud_outputs]
-            DMU.B[[j]]$target_input[datadea$ud_inputs] <- vtrans_i - DMU.B[[j]]$target_input[datadea$ud_inputs]
-            DMU.B[[j]]$target_output[datadea$ud_outputs] <- vtrans_o - DMU.B[[j]]$target_output[datadea$ud_outputs]
-          }
+    if (kkud1) { 
+      input.L <- datadea_old$input$mL - datadea_old$input$dL * (1 - a)
+      input.U <- datadea_old$input$mR + datadea_old$input$dR * (1 - a)
+      output.L <- datadea_old$output$mL - datadea_old$output$dL * (1 - a)
+      output.U <- datadea_old$output$mR + datadea_old$output$dR * (1 - a)
+      if (!is.null(DMU.W[[1]]$target_input)) {
+        for (j in 1:nde) {
+          DMU.W[[j]]$target_input[ud_inputs] <- vtrans_i - DMU.W[[j]]$target_input[ud_inputs]
+          DMU.W[[j]]$target_output[ud_outputs] <- vtrans_o - DMU.W[[j]]$target_output[ud_outputs]
+          DMU.B[[j]]$target_input[ud_inputs] <- vtrans_i - DMU.B[[j]]$target_input[ud_inputs]
+          DMU.B[[j]]$target_output[ud_outputs] <- vtrans_o - DMU.B[[j]]$target_output[ud_outputs]
         }
       }
     }
@@ -246,10 +294,8 @@ modelfuzzy_kaoliu <-
   
   deaOutput <- deasol
   
-  if (!is.null(datadea$ud_inputs) || !is.null(datadea$ud_outputs)) {
-    if (kaoliu_modelname %in% c("basic", "fdh")) { 
-      datadea <- datadea_old
-    }
+  if (kkud1) {
+    datadea <- datadea_old
   }
   
   deaOutput$modelname <- paste("fuzzy_kaoliu", deasol$modelname, sep = "_")
